==> react-image-annotate-master-3.0.3.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from "react";
import ReactDOM from "react-dom";
import Editor, { examples } from "./Editor";
import Annotator from "../Annotator";
import ErrorBoundaryDialog from "./ErrorBoundaryDialog.js";
export default (function () {
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      annotatorOpen = _useState2[0],
      changeAnnotatorOpen = _useState2[1];

  var _useState3 = useState(examples["Custom"]()),
      _useState4 = _slicedToArray(_useState3, 2),
      annotatorProps = _useState4[0],
      changeAnnotatorProps = _useState4[1];

  var _useState5 = useState(),
      _useState6 = _slicedToArray(_useState5, 2),
      lastOutput = _useState6[0],
      changeLastOutput = _useState6[1];

  return React.createElement("div", null, annotatorOpen ? React.createElement(ErrorBoundaryDialog, {
    onClose: function onClose() {
      changeAnnotatorOpen(false);
    }
  }, React.createElement("button", {
    onClick: function onClick(e) {
      e.stopPropagation();
      var element = document.getElementById("2050877559569606");

      if (element) {
        var clickEvent = document.createEvent("MouseEvents");
        clickEvent.initEvent("mousedown", true, true);
        element.dispatchEvent(clickEvent);
      }
    }
  }, "click"), React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onCreateAnno: function onCreateAnno(anno) {
      console.log("Annotator created: ", JSON.stringify(anno));
    },
    onClickAnno: function onClickAnno(anno) {
      console.log("Annotator click: ", anno);
    },
    onExit: function onExit(output) {
      var checkOutside = false;
      output.images[0].regions.forEach(function (r) {
        if (r.x <= 0 || r.x >= 1 || r.y <= 0 || r.y >= 1.0) {
          checkOutside = true;
        }
      });

      if (checkOutside) {
        alert("Create defect box inside image");
      } else {
        changeLastOutput(output.images[0].regions);
      }

      console.log(output.images[0].regions);
    }
  }))) : React.createElement(Editor, {
    lastOutput: lastOutput,
    onOpenAnnotator: function onOpenAnnotator(props) {
      changeAnnotatorProps(props);
      changeAnnotatorOpen(true);
    }
  }));
});

==> react-image-annotate-master-3.0.6.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from "react";
import ReactDOM from "react-dom";
import Editor, { examples } from "./Editor";
import Annotator from "../Annotator";
import ErrorBoundaryDialog from "./ErrorBoundaryDialog.js";
export default (function () {
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      annotatorOpen = _useState2[0],
      changeAnnotatorOpen = _useState2[1];

  var _useState3 = useState(examples["Custom"]()),
      _useState4 = _slicedToArray(_useState3, 2),
      annotatorProps = _useState4[0],
      changeAnnotatorProps = _useState4[1];

  var _useState5 = useState(),
      _useState6 = _slicedToArray(_useState5, 2),
      lastOutput = _useState6[0],
      changeLastOutput = _useState6[1];

  return React.createElement("div", null, annotatorOpen ? React.createElement(ErrorBoundaryDialog, {
    onClose: function onClose() {
      changeAnnotatorOpen(false);
    }
  }, React.createElement("button", {
    onClick: function onClick(e) {
      e.stopPropagation();
      var element = document.getElementById("delete-region-7725661632635865");

      if (element) {
        var clickEvent = document.createEvent("MouseEvents");
        clickEvent.initEvent("click", true, true);
        element.dispatchEvent(clickEvent);
      }
    }
  }, "click"), React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onCreateAnno: function onCreateAnno(anno) {
      console.log("Annotator created: ", JSON.stringify(anno));
    },
    onClickAnno: function onClickAnno(anno) {
      console.log("Annotator click: ", anno);
    },
    onExit: function onExit(output) {
      var checkOutside = false;
      output.images[0].regions.forEach(function (r) {
        if (r.x <= 0 || r.x >= 1 || r.y <= 0 || r.y >= 1.0) {
          checkOutside = true;
        }
      });

      if (checkOutside) {
        alert("Create defect box inside image");
      } else {
        changeLastOutput(output.images[0].regions);
      }

      console.log(output.images[0].regions);
    }
  }))) : React.createElement(Editor, {
    lastOutput: lastOutput,
    onOpenAnnotator: function onOpenAnnotator(props) {
      changeAnnotatorProps(props);
      changeAnnotatorOpen(true);
    }
  }));
});
